==========
 Examples
==========

.. contents:: :local:

Wizard
======

.. literalinclude:: ../examples/wizard.py

Warlock
=======

.. literalinclude:: ../examples/warlock.py

Rogue
=====

.. literalinclude:: ../examples/rogue.py
